int trigPin = 3; // Sensor trigger/control pin connected to Seeeduino Xiao pin 3
int echoPin = 5; // Sensor echo pin connected to Seeeduino Xiao pin 5
int ledPin = 8; // LED pin connected to Seeeduino Xiao pin 8

float pingTime; // Time for ping to travel to target and return
float targetDistance; // Distance from sensor to target
float speedOfSound = 343; // Speed of sound in meters per second (at 20°C)

void setup() {
  Serial.begin(9600); // Turn on serial port
  pinMode(trigPin, OUTPUT); // Sensor trig pin is an output
  pinMode(echoPin, INPUT); // Sensor echo pin is an input
  pinMode(ledPin, OUTPUT); // LED pin is an output
}

void loop() {
  digitalWrite(trigPin, LOW); // Set the trig pin low
  delayMicroseconds(2000); // Pause to let signal settle
  digitalWrite(trigPin, HIGH); // Set trig pin to high
  delayMicroseconds(15); // Pause in high state
  digitalWrite(trigPin, LOW); // Bring trig pin back to low

  pingTime = pulseIn(echoPin, HIGH); // Measure pingTime at echoPin in microseconds
  pingTime = pingTime / 1000000.; // Convert ping time to seconds

  targetDistance = speedOfSound * pingTime; // Calculate distance in meters
  targetDistance = targetDistance / 2; // Account for round trip of ping to target
  targetDistance *= 100; // Convert to centimeters

  Serial.print("Target Distance: ");
  Serial.print(targetDistance);
  Serial.println(" cm");

  // Adjust LED brightness based on target distance
  int brightness;
  if (targetDistance <= 2) {
    brightness = 0; // LED off
  } else {
    brightness = map(targetDistance, 2, 10, 0, 255); // Gradual brightness increase
  }
  analogWrite(ledPin, brightness); // Set LED brightness using PWM

  delay(1500);
}
